function CMIP5_print_EESSL(fldin,fldout,Scen,TR)
%CMIP5_print_EESSL prints a scatter map with the user-defined scenario and
%return period;

% fldin is the folder with the *.nc files;
% fldout is the output folder;
% Scen should be one of the following strings: HIS, R45, R85;
% Tr should be 5, 10, 20, 50, 100, 200, 500, 1000;


% i.e. Making the figures for all the scenarios and all the return periods:
% fldin='/path_to_downloaded_folder/nc_files';
% fldout='/path_to_downloaded_folder/png_files';
% s={'HIS','R45','R85'};
% t=[5 10 20 50 100 200 500 1000];
% for ii=1:size(s,2);
%     for jj=1:length(t);
%         CMIP5_print_EESSL(fldin,fldout,s{1,ii},t(jj));
%     end
% end

warning off;
        switch Scen
            case 'HIS';
                display('Historical Scenario has been selected')
                eessl=nc_varget(fullfile(fldin,'CoastAlRisk_Europe_EESSL_Historical.nc'),'ssl');
                strtitle='Historical scenario';
            case 'R45';
                display('RCP45 Scenario has been selected')
                eessl=nc_varget(fullfile(fldin,'CoastAlRisk_Europe_EESSL_RCP45.nc'),'ssl');
                strtitle='RCP45 scenario';
            case 'R85';
                display('RCP85 Scenario has been selected')
                eessl=nc_varget(fullfile(fldin,'CoastAlRisk_Europe_EESSL_RCP85.nc'),'ssl');
                strtitle='RCP85 scenario';
            otherwise
                error('Please select one of the following strings: HIS, R45, R85');
        end
        lo=nc_varget(fullfile(fldin,'CoastAlRisk_Europe_EESSL_Historical.nc'),'longitude'); % these parameters are the same for all the files;
        la=nc_varget(fullfile(fldin,'CoastAlRisk_Europe_EESSL_Historical.nc'),'latitude');
        alltr=nc_varget(fullfile(fldin,'CoastAlRisk_Europe_EESSL_Historical.nc'),'RP');
        
        kk=find(alltr==TR); % finding the user-requested return period;
        
        if isempty(kk);
            error('Please select one of the following return periods: 5, 10, 20, 50, 100, 200, 500, 100')
        else
        disp(sprintf('Return period of %d years has been selected',alltr(kk)))
        figure(1); hold on;
        set(gcf,'visible','off');
        drlo=[min(lo)-2, max(lo)+2]; 
        drla=[min(la)-2, max(la)+2];
%         m_proj('miller','long',drlo,'lat',drla);
        axesm('miller','maplatlimit',drla,'maplonlimit',drlo)
        geoshow('landareas.shp', 'FaceColor', [.83 .82 .78]);
        framem on; mlabel on; plabel on;gridm('on')
        setm(gca,'mlabelparallel',-90); % move the xticks at the bottom;
        setm(gca,'mlabellocation',15,'plabellocation',15,'mlinelocation',14,'plinelocation',15)
        hold on;
        tightmap;
%         m_gshhs_i('patch',[.83 .82 .78]);
        scatterm(la,lo,09,eessl(:,kk),'filled');
%        m_grid('fontsize',12,'fontname','times','box','fancy','tickdir','in');
        ch=colorbar;
        colormap('jet')
        caxis([min(min(eessl)) max(max(eessl))]);
        set(ch,'Fontsize',12,'fontname','times');
        set(ch,'YTick',[0:0.5:max(max(eessl))],'yticklabel',num2str([0:0.5:max(max(eessl))]','%3.1f'),'fontsize',14,'fontname','times');
        ylabel(ch,'(m)','fontsize',14,'fontname','times','rotation',90);
        set(gcf,'units','normalized','outerposition',[0 0 1 1]);
        set(gcf, 'renderer', 'painters');        set(gcf,'color','white');
        title(sprintf('European Extreme Storm Surge Level dataset\n %s: %d-yr Storm Surge Level (m)',strtitle,alltr(kk)),'fontname','times','fontsize',12);
        print(fullfile(fldout,sprintf('EESSL_%s_%d-yr',strtitle(1:end-9),alltr(kk))),'-dpng');
        close all
        end
    
end
